# coding: utf-8

"""
    Kestra EE

    All API operations, except for Superadmin-only endpoints, require a tenant identifier in the HTTP path.<br/> Endpoints designated as Superadmin-only are not tenant-scoped.

    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class ResourceType(str, Enum):
    """
    ResourceType
    """

    """
    allowed enum values
    """
    AUDITLOG = 'AUDITLOG'
    APP = 'APP'
    ASSET = 'ASSET'
    APP_EXECUTION = 'APP_EXECUTION'
    BLUEPRINT = 'BLUEPRINT'
    BINDING = 'BINDING'
    DASHBOARD = 'DASHBOARD'
    EXECUTION = 'EXECUTION'
    FLOW = 'FLOW'
    KV_STORE = 'KV_STORE'
    GROUP = 'GROUP'
    INVITATION = 'INVITATION'
    NAMESPACE = 'NAMESPACE'
    NAMESPACE_FILE = 'NAMESPACE_FILE'
    ROLE = 'ROLE'
    SECURITY_INTEGRATION = 'SECURITY_INTEGRATION'
    SECRET = 'SECRET'
    SETTING = 'SETTING'
    TEMPLATE = 'TEMPLATE'
    TRIGGER = 'TRIGGER'
    TENANT = 'TENANT'
    TENANT_ACCESS = 'TENANT_ACCESS'
    TESTSUITE = 'TESTSUITE'
    TESTSUITE_RUN = 'TESTSUITE_RUN'
    VERSIONED_PLUGIN = 'VERSIONED_PLUGIN'
    USER = 'USER'
    WORKER_GROUP = 'WORKER_GROUP'
    INSTANCE = 'INSTANCE'
    UNKNOWN = 'UNKNOWN'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ResourceType from a JSON string"""
        return cls(json.loads(json_str))


