# coding: utf-8

"""
    Kestra EE

    All API operations, except for Superadmin-only endpoints, require a tenant identifier in the HTTP path.<br/> Endpoints designated as Superadmin-only are not tenant-scoped.

    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class Type(str, Enum):
    """
    Type
    """

    """
    allowed enum values
    """
    STRING = 'STRING'
    ENUM = 'ENUM'
    SELECT = 'SELECT'
    INT = 'INT'
    FLOAT = 'FLOAT'
    BOOLEAN = 'BOOLEAN'
    BOOL = 'BOOL'
    DATETIME = 'DATETIME'
    DATE = 'DATE'
    TIME = 'TIME'
    DURATION = 'DURATION'
    FILE = 'FILE'
    JSON = 'JSON'
    URI = 'URI'
    SECRET = 'SECRET'
    ARRAY = 'ARRAY'
    MULTISELECT = 'MULTISELECT'
    YAML = 'YAML'
    EMAIL = 'EMAIL'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of Type from a JSON string"""
        return cls(json.loads(json_str))


