# coding: utf-8

"""
    Kestra EE

    All API operations, except for Superadmin-only endpoints, require a tenant identifier in the HTTP path.<br/> Endpoints designated as Superadmin-only are not tenant-scoped.

    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import regex as re
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from kestrapy.models.assets_in_out import AssetsInOut
from kestrapy.models.state import State
from kestrapy.models.task_run_attempt import TaskRunAttempt
from typing import Optional, Set
from typing_extensions import Self

class TaskRun(BaseModel):
    """
    TaskRun
    """ # noqa: E501
    id: StrictStr
    execution_id: StrictStr = Field(alias="executionId")
    namespace: StrictStr
    flow_id: StrictStr = Field(alias="flowId")
    task_id: StrictStr = Field(alias="taskId")
    parent_task_run_id: Optional[StrictStr] = Field(default=None, alias="parentTaskRunId")
    value: Optional[StrictStr] = None
    attempts: Optional[List[TaskRunAttempt]] = None
    outputs: Optional[Dict[str, Any]] = None
    assets: Optional[AssetsInOut] = None
    state: State
    iteration: Optional[StrictInt] = None
    dynamic: Optional[StrictBool] = None
    force_execution: Optional[StrictBool] = Field(default=None, alias="forceExecution")
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = ["id", "executionId", "namespace", "flowId", "taskId", "parentTaskRunId", "value", "attempts", "outputs", "assets", "state", "iteration", "dynamic", "forceExecution"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TaskRun from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        excluded_fields: Set[str] = set([
            "additional_properties",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in attempts (list)
        _items = []
        if self.attempts:
            for _item_attempts in self.attempts:
                if _item_attempts:
                    _items.append(_item_attempts.to_dict())
            _dict['attempts'] = _items
        # override the default output from pydantic by calling `to_dict()` of assets
        if self.assets:
            _dict['assets'] = self.assets.to_dict()
        # override the default output from pydantic by calling `to_dict()` of state
        if self.state:
            _dict['state'] = self.state.to_dict()
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        # set to None if outputs (nullable) is None
        # and model_fields_set contains the field
        if self.outputs is None and "outputs" in self.model_fields_set:
            _dict['outputs'] = None

        # set to None if assets (nullable) is None
        # and model_fields_set contains the field
        if self.assets is None and "assets" in self.model_fields_set:
            _dict['assets'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TaskRun from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "executionId": obj.get("executionId"),
            "namespace": obj.get("namespace"),
            "flowId": obj.get("flowId"),
            "taskId": obj.get("taskId"),
            "parentTaskRunId": obj.get("parentTaskRunId"),
            "value": obj.get("value"),
            "attempts": [TaskRunAttempt.from_dict(_item) for _item in obj["attempts"]] if obj.get("attempts") is not None else None,
            "outputs": obj.get("outputs"),
            "assets": AssetsInOut.from_dict(obj["assets"]) if obj.get("assets") is not None else None,
            "state": State.from_dict(obj["state"]) if obj.get("state") is not None else None,
            "iteration": obj.get("iteration"),
            "dynamic": obj.get("dynamic"),
            "forceExecution": obj.get("forceExecution")
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj


