# coding: utf-8

"""
    Kestra EE

    All API operations, except for Superadmin-only endpoints, require a tenant identifier in the HTTP path.<br/> Endpoints designated as Superadmin-only are not tenant-scoped.

    The version of the OpenAPI document: 1.1.4
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from kestrapy.api.service_account_api import ServiceAccountApi


class TestServiceAccountApi(unittest.TestCase):
    """ServiceAccountApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ServiceAccountApi()

    def tearDown(self) -> None:
        pass

    def test_create_api_tokens_for_service_account(self) -> None:
        """Test case for create_api_tokens_for_service_account

        Create new API Token for a specific service account
        """
        pass

    def test_create_api_tokens_for_service_account_with_tenant(self) -> None:
        """Test case for create_api_tokens_for_service_account_with_tenant

        Create new API Token for a specific service account
        """
        pass

    def test_create_service_account(self) -> None:
        """Test case for create_service_account

        Create a service account
        """
        pass

    def test_create_service_account_for_tenant(self) -> None:
        """Test case for create_service_account_for_tenant

        Create a service account for the given tenant
        """
        pass

    def test_delete_api_token_for_service_account(self) -> None:
        """Test case for delete_api_token_for_service_account

        Delete an API Token for specific service account and token id
        """
        pass

    def test_delete_api_token_for_service_account_with_tenant(self) -> None:
        """Test case for delete_api_token_for_service_account_with_tenant

        Delete an API Token for specific service account and token id
        """
        pass

    def test_delete_service_account(self) -> None:
        """Test case for delete_service_account

        Delete a service account
        """
        pass

    def test_delete_service_account_for_tenant(self) -> None:
        """Test case for delete_service_account_for_tenant

        Delete a service account
        """
        pass

    def test_list_api_tokens_for_service_account(self) -> None:
        """Test case for list_api_tokens_for_service_account

        List API tokens for a specific service account
        """
        pass

    def test_list_api_tokens_for_service_account_with_tenant(self) -> None:
        """Test case for list_api_tokens_for_service_account_with_tenant

        List API tokens for a specific service account
        """
        pass

    def test_list_service_accounts(self) -> None:
        """Test case for list_service_accounts

        List service accounts. Superadmin-only. 
        """
        pass

    def test_patch_service_account_details(self) -> None:
        """Test case for patch_service_account_details

        Update service account details
        """
        pass

    def test_patch_service_account_super_admin(self) -> None:
        """Test case for patch_service_account_super_admin

        Update service account superadmin privileges
        """
        pass

    def test_service_account(self) -> None:
        """Test case for service_account

        Get a service account
        """
        pass

    def test_service_account_for_tenant(self) -> None:
        """Test case for service_account_for_tenant

        Retrieve a service account
        """
        pass

    def test_update_service_account(self) -> None:
        """Test case for update_service_account

        Update a user service account
        """
        pass


if __name__ == '__main__':
    unittest.main()
