# coding: utf-8

"""
    Kestra EE

    All API operations, except for Superadmin-only endpoints, require a tenant identifier in the HTTP path.<br/> Endpoints designated as Superadmin-only are not tenant-scoped.

    The version of the OpenAPI document: 1.1.4
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from kestrapy.api.roles_api import RolesApi


class TestRolesApi(unittest.TestCase):
    """RolesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = RolesApi()

    def tearDown(self) -> None:
        pass

    def test_autocomplete_roles(self) -> None:
        """Test case for autocomplete_roles

        List roles for autocomplete
        """
        pass

    def test_create_role(self) -> None:
        """Test case for create_role

        Create a role
        """
        pass

    def test_delete_role(self) -> None:
        """Test case for delete_role

        Delete a role
        """
        pass

    def test_list_roles_from_given_ids(self) -> None:
        """Test case for list_roles_from_given_ids

        List roles by ids
        """
        pass

    def test_role(self) -> None:
        """Test case for role

        Retrieve a role
        """
        pass

    def test_search_roles(self) -> None:
        """Test case for search_roles

        Search for roles
        """
        pass

    def test_update_role(self) -> None:
        """Test case for update_role

        Update a role
        """
        pass


if __name__ == '__main__':
    unittest.main()
