# coding: utf-8

"""
    Kestra EE

    All API operations, except for Superadmin-only endpoints, require a tenant identifier in the HTTP path.<br/> Endpoints designated as Superadmin-only are not tenant-scoped.

    The version of the OpenAPI document: 1.1.4
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from kestrapy.api.kv_api import KVApi


class TestKVApi(unittest.TestCase):
    """KVApi unit test stubs"""

    def setUp(self) -> None:
        self.api = KVApi()

    def tearDown(self) -> None:
        pass

    def test_delete_key_value(self) -> None:
        """Test case for delete_key_value

        Delete a key-value pair
        """
        pass

    def test_delete_key_values(self) -> None:
        """Test case for delete_key_values

        Bulk-delete multiple key/value pairs from the given namespace.
        """
        pass

    def test_key_value(self) -> None:
        """Test case for key_value

        Get value for a key
        """
        pass

    def test_list_all_keys(self) -> None:
        """Test case for list_all_keys

        List all keys
        """
        pass

    def test_list_keys_with_inheritence(self) -> None:
        """Test case for list_keys_with_inheritence

        List all keys for inherited namespaces
        """
        pass

    def test_set_key_value(self) -> None:
        """Test case for set_key_value

        Puts a key-value pair in store
        """
        pass


if __name__ == '__main__':
    unittest.main()
