# coding: utf-8

"""
    Kestra EE

    All API operations, except for Superadmin-only endpoints, require a tenant identifier in the HTTP path.<br/> Endpoints designated as Superadmin-only are not tenant-scoped.

    The version of the OpenAPI document: 1.1.4
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from kestrapy.api.executions_api import ExecutionsApi


class TestExecutionsApi(unittest.TestCase):
    """ExecutionsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ExecutionsApi()

    def tearDown(self) -> None:
        pass

    def test_create_execution(self) -> None:
        """Test case for create_execution

        Create a new execution for a flow
        """
        pass

    def test_delete_execution(self) -> None:
        """Test case for delete_execution

        Delete an execution
        """
        pass

    def test_delete_executions_by_ids(self) -> None:
        """Test case for delete_executions_by_ids

        Delete a list of executions
        """
        pass

    def test_delete_executions_by_query(self) -> None:
        """Test case for delete_executions_by_query

        Delete executions filter by query parameters
        """
        pass

    def test_download_file_from_execution(self) -> None:
        """Test case for download_file_from_execution

        Download file for an execution
        """
        pass

    def test_execution(self) -> None:
        """Test case for execution

        Get an execution
        """
        pass

    def test_execution_flow_graph(self) -> None:
        """Test case for execution_flow_graph

        Generate a graph for an execution
        """
        pass

    def test_file_metadatas_from_execution(self) -> None:
        """Test case for file_metadatas_from_execution

        Get file meta information for an execution
        """
        pass

    def test_flow_from_execution(self) -> None:
        """Test case for flow_from_execution

        Get flow information's for an execution
        """
        pass

    def test_flow_from_execution_by_id(self) -> None:
        """Test case for flow_from_execution_by_id

        Get flow information's for an execution
        """
        pass

    def test_follow_dependencies_executions(self) -> None:
        """Test case for follow_dependencies_executions

        Follow all execution dependencies executions
        """
        pass

    def test_follow_execution(self) -> None:
        """Test case for follow_execution

        Follow an execution
        """
        pass

    def test_force_run_by_ids(self) -> None:
        """Test case for force_run_by_ids

        Force run a list of executions
        """
        pass

    def test_force_run_execution(self) -> None:
        """Test case for force_run_execution

        Force run an execution
        """
        pass

    def test_force_run_executions_by_query(self) -> None:
        """Test case for force_run_executions_by_query

        Force run executions filter by query parameters
        """
        pass

    def test_kill_execution(self) -> None:
        """Test case for kill_execution

        Kill an execution
        """
        pass

    def test_kill_executions_by_ids(self) -> None:
        """Test case for kill_executions_by_ids

        Kill a list of executions
        """
        pass

    def test_kill_executions_by_query(self) -> None:
        """Test case for kill_executions_by_query

        Kill executions filter by query parameters
        """
        pass

    def test_latest_executions(self) -> None:
        """Test case for latest_executions

        Get the latest execution for given flows
        """
        pass

    def test_pause_execution(self) -> None:
        """Test case for pause_execution

        Pause a running execution.
        """
        pass

    def test_pause_executions_by_ids(self) -> None:
        """Test case for pause_executions_by_ids

        Pause a list of running executions
        """
        pass

    def test_pause_executions_by_query(self) -> None:
        """Test case for pause_executions_by_query

        Pause executions filter by query parameters
        """
        pass

    def test_replay_execution(self) -> None:
        """Test case for replay_execution

        Create a new execution from an old one and start it from a specified task run id
        """
        pass

    def test_replay_execution_withinputs(self) -> None:
        """Test case for replay_execution_withinputs

        Create a new execution from an old one and start it from a specified task run id
        """
        pass

    def test_replay_executions_by_ids(self) -> None:
        """Test case for replay_executions_by_ids

        Create new executions from old ones. Keep the flow revision
        """
        pass

    def test_replay_executions_by_query(self) -> None:
        """Test case for replay_executions_by_query

        Create new executions from old ones filter by query parameters. Keep the flow revision
        """
        pass

    def test_restart_execution(self) -> None:
        """Test case for restart_execution

        Restart a new execution from an old one
        """
        pass

    def test_restart_executions_by_ids(self) -> None:
        """Test case for restart_executions_by_ids

        Restart a list of executions
        """
        pass

    def test_restart_executions_by_query(self) -> None:
        """Test case for restart_executions_by_query

        Restart executions filter by query parameters
        """
        pass

    def test_resume_execution(self) -> None:
        """Test case for resume_execution

        Resume a paused execution.
        """
        pass

    def test_resume_executions_by_ids(self) -> None:
        """Test case for resume_executions_by_ids

        Resume a list of paused executions
        """
        pass

    def test_resume_executions_by_query(self) -> None:
        """Test case for resume_executions_by_query

        Resume executions filter by query parameters
        """
        pass

    def test_search_concurrency_limits(self) -> None:
        """Test case for search_concurrency_limits

        Search for flow concurrency limits
        """
        pass

    def test_search_executions(self) -> None:
        """Test case for search_executions

        Search for executions
        """
        pass

    def test_search_executions_by_flow_id(self) -> None:
        """Test case for search_executions_by_flow_id

        Search for executions for a flow
        """
        pass

    def test_set_labels_on_terminated_execution(self) -> None:
        """Test case for set_labels_on_terminated_execution

        Add or update labels of a terminated execution
        """
        pass

    def test_set_labels_on_terminated_executions_by_ids(self) -> None:
        """Test case for set_labels_on_terminated_executions_by_ids

        Set labels on a list of executions
        """
        pass

    def test_set_labels_on_terminated_executions_by_query(self) -> None:
        """Test case for set_labels_on_terminated_executions_by_query

        Set label on executions filter by query parameters
        """
        pass

    def test_trigger_execution_by_get_webhook(self) -> None:
        """Test case for trigger_execution_by_get_webhook

        Trigger a new execution by GET webhook trigger
        """
        pass

    def test_unqueue_execution(self) -> None:
        """Test case for unqueue_execution

        Unqueue an execution
        """
        pass

    def test_unqueue_executions_by_ids(self) -> None:
        """Test case for unqueue_executions_by_ids

        Unqueue a list of executions
        """
        pass

    def test_unqueue_executions_by_query(self) -> None:
        """Test case for unqueue_executions_by_query

        Unqueue executions filter by query parameters
        """
        pass

    def test_update_concurrency_limit(self) -> None:
        """Test case for update_concurrency_limit

        Update a flow concurrency limit
        """
        pass

    def test_update_execution_status(self) -> None:
        """Test case for update_execution_status

        Change the state of an execution
        """
        pass

    def test_update_executions_status_by_ids(self) -> None:
        """Test case for update_executions_status_by_ids

        Change executions state by id
        """
        pass

    def test_update_executions_status_by_query(self) -> None:
        """Test case for update_executions_status_by_query

        Change executions state by query parameters
        """
        pass


if __name__ == '__main__':
    unittest.main()
