# coding: utf-8

"""
    Kestra EE

    All API operations, except for Superadmin-only endpoints, require a tenant identifier in the HTTP path.<br/> Endpoints designated as Superadmin-only are not tenant-scoped.

    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class QueryFilterField(str, Enum):
    """
    QueryFilterField
    """

    """
    allowed enum values
    """
    QUERY = 'QUERY'
    SCOPE = 'SCOPE'
    NAMESPACE = 'NAMESPACE'
    KIND = 'KIND'
    LABELS = 'LABELS'
    METADATA = 'METADATA'
    FLOW_ID = 'FLOW_ID'
    FLOW_REVISION = 'FLOW_REVISION'
    ID = 'ID'
    ASSET_ID = 'ASSET_ID'
    TYPE = 'TYPE'
    CREATED = 'CREATED'
    UPDATED = 'UPDATED'
    START_DATE = 'START_DATE'
    END_DATE = 'END_DATE'
    STATE = 'STATE'
    TIME_RANGE = 'TIME_RANGE'
    TRIGGER_EXECUTION_ID = 'TRIGGER_EXECUTION_ID'
    TRIGGER_ID = 'TRIGGER_ID'
    TRIGGER_STATE = 'TRIGGER_STATE'
    EXECUTION_ID = 'EXECUTION_ID'
    TASK_ID = 'TASK_ID'
    TASK_RUN_ID = 'TASK_RUN_ID'
    CHILD_FILTER = 'CHILD_FILTER'
    WORKER_ID = 'WORKER_ID'
    EXISTING_ONLY = 'EXISTING_ONLY'
    MIN_LEVEL = 'MIN_LEVEL'
    PATH = 'PATH'
    PARENT_PATH = 'PARENT_PATH'
    VERSION = 'VERSION'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of QueryFilterField from a JSON string"""
        return cls(json.loads(json_str))


