# coding: utf-8

"""
    Kestra EE

    All API operations, except for Superadmin-only endpoints, require a tenant identifier in the HTTP path.<br/> Endpoints designated as Superadmin-only are not tenant-scoped.

    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import regex as re
import json

from pydantic import BaseModel, ConfigDict
from typing import Any, ClassVar, Dict, List, Optional
from kestrapy.models.execution_usage import ExecutionUsage
from kestrapy.models.flow_usage import FlowUsage
from kestrapy.models.group_usage import GroupUsage
from kestrapy.models.role_usage import RoleUsage
from kestrapy.models.tenant_usage import TenantUsage
from kestrapy.models.user_usage import UserUsage
from typing import Optional, Set
from typing_extensions import Self

class UsageEE(BaseModel):
    """
    UsageEE
    """ # noqa: E501
    flows: Optional[FlowUsage] = None
    executions: Optional[ExecutionUsage] = None
    groups: Optional[GroupUsage] = None
    users: Optional[UserUsage] = None
    roles: Optional[RoleUsage] = None
    tenants: Optional[TenantUsage] = None
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = ["flows", "executions", "groups", "users", "roles", "tenants"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of UsageEE from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        excluded_fields: Set[str] = set([
            "additional_properties",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of flows
        if self.flows:
            _dict['flows'] = self.flows.to_dict()
        # override the default output from pydantic by calling `to_dict()` of executions
        if self.executions:
            _dict['executions'] = self.executions.to_dict()
        # override the default output from pydantic by calling `to_dict()` of groups
        if self.groups:
            _dict['groups'] = self.groups.to_dict()
        # override the default output from pydantic by calling `to_dict()` of users
        if self.users:
            _dict['users'] = self.users.to_dict()
        # override the default output from pydantic by calling `to_dict()` of roles
        if self.roles:
            _dict['roles'] = self.roles.to_dict()
        # override the default output from pydantic by calling `to_dict()` of tenants
        if self.tenants:
            _dict['tenants'] = self.tenants.to_dict()
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of UsageEE from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "flows": FlowUsage.from_dict(obj["flows"]) if obj.get("flows") is not None else None,
            "executions": ExecutionUsage.from_dict(obj["executions"]) if obj.get("executions") is not None else None,
            "groups": GroupUsage.from_dict(obj["groups"]) if obj.get("groups") is not None else None,
            "users": UserUsage.from_dict(obj["users"]) if obj.get("users") is not None else None,
            "roles": RoleUsage.from_dict(obj["roles"]) if obj.get("roles") is not None else None,
            "tenants": TenantUsage.from_dict(obj["tenants"]) if obj.get("tenants") is not None else None
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj


